@@ -7,7 +7,7 @@ import (
 	"os"
 	"os/exec"
 
-	"github.com/bmf-san/ggc/v4/git"
+	"github.com/bmf-san/ggc/v5/git"
 )
 
 // Logger provides functionality for the log command.
@@ -19,12 +19,7 @@ type Logger struct {
 }
 
 // NewLogger creates a new Logger.
-func NewLogger() *Logger {
-	return NewLoggerWithClient(git.NewClient())
-}
-
-// NewLoggerWithClient creates a new Logger with the specified git client.
-func NewLoggerWithClient(client git.Clienter) *Logger {
+func NewLogger(client git.Clienter) *Logger {
 	l := &Logger{
 		gitClient:    client,
 		outputWriter: os.Stdout,
