@@ -6,7 +6,7 @@ import (
 	"io"
 	"os"
 
-	"github.com/bmf-san/ggc/v4/git"
+	"github.com/bmf-san/ggc/v5/git"
 )
 
 // Pusher provides functionality for the push command.
@@ -17,12 +17,7 @@ type Pusher struct {
 }
 
 // NewPusher creates a new Pusher.
-func NewPusher() *Pusher {
-	return NewPusherWithClient(git.NewClient())
-}
-
-// NewPusherWithClient creates a new Pusher with the specified git client.
-func NewPusherWithClient(client git.Clienter) *Pusher {
+func NewPusher(client git.Clienter) *Pusher {
 	p := &Pusher{
 		gitClient:    client,
 		outputWriter: os.Stdout,
