@@ -5,6 +5,8 @@ import (
 	"os/exec"
 	"strings"
 	"testing"
+
+	"github.com/bmf-san/ggc/v5/internal/testutil"
 )
 
 func TestVersioneer_Version(t *testing.T) {
@@ -58,6 +60,7 @@ func TestVersioneer_Version(t *testing.T) {
 
 			var buf bytes.Buffer
 			v := &Versioneer{
+				gitClient:    testutil.NewMockGitClient(),
 				outputWriter: &buf,
 				helper:       NewHelper(),
 				execCommand:  exec.Command,
