@@ -7,11 +7,20 @@ import (
 	"os/exec"
 	"path/filepath"
 	"reflect"
+	"regexp"
+	"runtime"
 	"strings"
 
-	"gopkg.in/yaml.v3"
+	"github.com/bmf-san/ggc/v5/git"
+	"go.yaml.in/yaml/v3"
 )
 
+// GitConfigExecutor interface for git config operations (for testing)
+type GitConfigExecutor interface {
+	ConfigSetGlobal(key, value string) error
+	ConfigGetGlobal(key string) (string, error)
+}
+
 // Config represents the complete configuration structure
 type Config struct {
 	Meta struct {
@@ -72,12 +81,25 @@ type ParsedAlias struct {
 type Manager struct {
 	config     *Config
 	configPath string
+	gitClient  git.Clienter
 }
 
-// NewConfigManager creates a new configuration manager
-func NewConfigManager() *Manager {
+var (
+	// Accept classic GitHub tokens like ghp_, gho_, ghu_, ghs_, ghr_
+	githubTokenClassicRe = regexp.MustCompile(`^gh[opusr]_[A-Za-z0-9]{20,250}$`)
+	// Accept fine-grained PATs starting with github_pat_
+	githubTokenFineRe = regexp.MustCompile(`^github_pat_[A-Za-z0-9_-]{20,255}$`)
+	// Accept GitLab tokens with optional glpat- prefix
+	gitlabTokenRe = regexp.MustCompile(`^(glpat-)?[A-Za-z0-9_-]{20,100}$`)
+	// Allow slashes; additional structural checks are applied separately
+	gitRemoteNameCharsRe = regexp.MustCompile(`^[A-Za-z0-9._/\-]+$`)
+)
+
+// NewConfigManager creates a new configuration manager with the provided git client
+func NewConfigManager(gitClient git.Clienter) *Manager {
 	return &Manager{
-		config: getDefaultConfig(),
+		config:    getDefaultConfig(gitClient),
+		gitClient: gitClient,
 	}
 }
 
@@ -106,10 +128,28 @@ func (c *Config) validateBranch() error {
 }
 
 func (c *Config) validateEditor() error {
-	editor := c.Default.Editor
-	_, err := exec.LookPath(editor)
-	if err != nil {
-		return &ValidationError{"default.editor", editor, "command not found in PATH"}
+	editor := strings.TrimSpace(c.Default.Editor)
+	// Extract the first token, supporting simple quoted paths with spaces
+	bin := editor
+	if editor != "" {
+		if (strings.HasPrefix(editor, "\"") && strings.Count(editor, "\"") >= 2) || (strings.HasPrefix(editor, "'") && strings.Count(editor, "'") >= 2) {
+			q := editor[0:1]
+			if idx := strings.Index(editor[1:], q); idx >= 0 {
+				bin = editor[1 : 1+idx]
+			}
+		} else if i := strings.IndexAny(editor, " \t"); i > 0 {
+			bin = editor[:i]
+		}
+	}
+
+	// If the binary looks like a path, accept it if it exists; else use PATH lookup
+	if strings.ContainsAny(bin, "/\\") {
+		if _, err := os.Stat(bin); err == nil {
+			return nil
+		}
+	}
+	if _, err := exec.LookPath(bin); err != nil {
+		return &ValidationError{"default.editor", editor, "command not found in PATH or invalid path"}
 	}
 	return nil
 }
@@ -125,29 +165,41 @@ func (c *Config) validateConfirmDestructive() error {
 
 func (c *Config) validateIntegrationTokens() error {
 	ghToken := c.Integration.Github.Token
-	if ghToken != "" && !strings.HasPrefix(ghToken, "ghp_") {
-		return &ValidationError{
-			Field:   "integration.github.token",
-			Value:   ghToken,
-			Message: "GitHub token must start with 'ghp_'",
+	if ghToken != "" {
+		if !githubTokenClassicRe.MatchString(ghToken) && !githubTokenFineRe.MatchString(ghToken) {
+			return &ValidationError{
+				Field:   "integration.github.token",
+				Value:   "[REDACTED]",
+				Message: "GitHub token must be a valid classic (gh[pousr]_) or fine-grained (github_pat_) token",
+			}
 		}
 	}
 
 	glToken := c.Integration.Gitlab.Token
-	if glToken != "" && len(glToken) < 20 {
-		return &ValidationError{
-			Field:   "integration.gitlab.token",
-			Value:   glToken,
-			Message: "GitLab token seems too short to be valid",
+	if glToken != "" {
+		if !gitlabTokenRe.MatchString(glToken) {
+			return &ValidationError{
+				Field:   "integration.gitlab.token",
+				Value:   "[REDACTED]",
+				Message: "GitLab token must be 20-100 characters (alphanumeric, _ or -), with optional glpat- prefix",
+			}
 		}
 	}
 
 	if remote := c.Integration.Github.DefaultRemote; remote != "" {
-		if strings.Contains(remote, " ") || strings.Contains(remote, "/") {
+		if !gitRemoteNameCharsRe.MatchString(remote) || strings.Contains(remote, " ") {
 			return &ValidationError{
 				Field:   "integration.github.default-remote",
 				Value:   remote,
-				Message: "Default remote must be a valid Git remote name (no spaces or slashes)",
+				Message: "Remote may contain letters, digits, ., _, -, and / only",
+			}
+		}
+		// Additional structural checks: no leading/trailing '.' or '/', and no empty/unsafe segments
+		if strings.HasPrefix(remote, "/") || strings.HasSuffix(remote, "/") || strings.HasPrefix(remote, ".") || strings.HasSuffix(remote, ".") || strings.Contains(remote, "//") || strings.Contains(remote, "..") {
+			return &ValidationError{
+				Field:   "integration.github.default-remote",
+				Value:   remote,
+				Message: "Remote must not start/end with '.' or '/', nor contain '..' or '//'",
 			}
 		}
 	}
@@ -281,37 +333,12 @@ func (c *Config) GetAllAliases() map[string]*ParsedAlias {
 	return result
 }
 
-func getGitVersion() string {
-	cmd := exec.Command("git", "describe", "--tags", "--always", "--dirty")
-	output, err := cmd.Output()
-	if err != nil {
-		return "dev"
-	}
-	return strings.TrimSpace(string(output))
-}
-
-func getGitCommit() string {
-	cmd := exec.Command("git", "rev-parse", "--short", "HEAD")
-	output, err := cmd.Output()
-	if err != nil {
-		return "unknown"
-	}
-	return strings.TrimSpace(string(output))
-}
-
-func (c *Config) updateMeta() {
-	version, commit := getGitVersion(), getGitCommit()
-
-	c.Meta.Version = version
-	c.Meta.Commit = commit
-
-	if c.Meta.ConfigVersion == "" {
-		c.Meta.ConfigVersion = "1.0"
-	}
-}
+// Note: getGitVersion, getGitCommit, and updateMeta functions removed
+// to eliminate direct git command execution. Meta values are now set
+// manually in getDefaultConfig() to avoid side effects in tests.
 
 // getDefaultConfig returns the default configuration values
-func getDefaultConfig() *Config {
+func getDefaultConfig(gitClient git.Clienter) *Config {
 	config := &Config{
 		Aliases: make(map[string]interface{}),
 	}
@@ -331,7 +358,23 @@ func getDefaultConfig() *Config {
 
 	config.Integration.Github.DefaultRemote = "origin"
 
-	config.updateMeta()
+	// Set meta values using gitClient
+	if version, err := gitClient.GetVersion(); err == nil {
+		config.Meta.Version = version
+	} else {
+		config.Meta.Version = "dev"
+	}
+
+	if commit, err := gitClient.GetCommitHash(); err == nil {
+		config.Meta.Commit = commit
+	} else {
+		config.Meta.Commit = "unknown"
+	}
+
+	// Only set ConfigVersion if it's empty (preserving original updateMeta behavior)
+	if config.Meta.ConfigVersion == "" {
+		config.Meta.ConfigVersion = "1.0"
+	}
 
 	return config
 }
@@ -371,7 +414,7 @@ func (cm *Manager) loadFromFile(path string) error {
 		return fmt.Errorf("failed to read config file: %w", err)
 	}
 
-	config := getDefaultConfig()
+	config := getDefaultConfig(cm.gitClient)
 	if err := yaml.Unmarshal(data, config); err != nil {
 		return fmt.Errorf("failed to parse config file: %w", err)
 	}
@@ -381,27 +424,8 @@ func (cm *Manager) loadFromFile(path string) error {
 	return nil
 }
 
-// setGitConfig sets a git configuration value using git config command
-func (cm *Manager) setGitConfig(key, value string) error {
-	cmd := exec.Command("git", "config", "--global", key, value)
-	if err := cmd.Run(); err != nil {
-		return fmt.Errorf("failed to run git config: %w", err)
-	}
-	return nil
-}
-
-// getGitConfig retrieves a git configuration value
-func (cm *Manager) getGitConfig(key string) (string, error) {
-	cmd := exec.Command("git", "config", "--global", key)
-	output, err := cmd.Output()
-	if err != nil {
-		return "", fmt.Errorf("failed to get git config: %w", err)
-	}
-	return strings.TrimSpace(string(output)), nil
-}
-
 func (cm *Manager) syncFromCommandName(command string) {
-	if value, err := cm.getGitConfig(command); err == nil && value != "" {
+	if value, err := cm.gitClient.ConfigGetGlobal(command); err == nil && value != "" {
 		switch command {
 		case "core.editor":
 			cm.config.Default.Editor = value
@@ -441,19 +465,19 @@ func (cm *Manager) syncToGitConfig() error {
 	config := cm.GetConfig()
 
 	if config.Default.Editor != "" {
-		if err := cm.setGitConfig("core.editor", config.Default.Editor); err != nil {
+		if err := cm.gitClient.ConfigSetGlobal("core.editor", config.Default.Editor); err != nil {
 			return fmt.Errorf("failed to set git editor: %w", err)
 		}
 	}
 
 	if config.Default.MergeTool != "" {
-		if err := cm.setGitConfig("merge.tool", config.Default.MergeTool); err != nil {
+		if err := cm.gitClient.ConfigSetGlobal("merge.tool", config.Default.MergeTool); err != nil {
 			return fmt.Errorf("failed to set git merge tool: %w", err)
 		}
 	}
 
 	if config.Default.Branch != "" {
-		if err := cm.setGitConfig("init.defaultBranch", config.Default.Branch); err != nil {
+		if err := cm.gitClient.ConfigSetGlobal("init.defaultBranch", config.Default.Branch); err != nil {
 			return fmt.Errorf("failed to set git default branch: %w", err)
 		}
 	}
@@ -462,7 +486,7 @@ func (cm *Manager) syncToGitConfig() error {
 	if config.UI.Color {
 		colorValue = "true"
 	}
-	if err := cm.setGitConfig("color.ui", colorValue); err != nil {
+	if err := cm.gitClient.ConfigSetGlobal("color.ui", colorValue); err != nil {
 		return fmt.Errorf("failed to set git color: %w", err)
 	}
 
@@ -470,23 +494,23 @@ func (cm *Manager) syncToGitConfig() error {
 	if config.Behavior.AutoFetch {
 		autoFetchValue = "true"
 	}
-	if err := cm.setGitConfig("fetch.auto", autoFetchValue); err != nil {
+	if err := cm.gitClient.ConfigSetGlobal("fetch.auto", autoFetchValue); err != nil {
 		return fmt.Errorf("failed to set git autofetch: %w", err)
 	}
 
-	if err := cm.setGitConfig("push.default", config.Behavior.ConfirmDestructive); err != nil {
+	if err := cm.gitClient.ConfigSetGlobal("push.default", config.Behavior.ConfirmDestructive); err != nil {
 		return fmt.Errorf("failed to set git push default: %w", err)
 	}
 
 	if !config.UI.Pager {
-		if err := cm.setGitConfig("core.pager", "cat"); err != nil {
+		if err := cm.gitClient.ConfigSetGlobal("core.pager", "cat"); err != nil {
 			return fmt.Errorf("failed to set git pager: %w", err)
 		}
 	}
 
 	for alias, value := range config.Aliases {
 		if cmdStr, ok := value.(string); ok {
-			if err := cm.setGitConfig(fmt.Sprintf("alias.%s", alias), cmdStr); err != nil {
+			if err := cm.gitClient.ConfigSetGlobal(fmt.Sprintf("alias.%s", alias), cmdStr); err != nil {
 				return fmt.Errorf("failed to set git alias.%s: %w", alias, err)
 			}
 		}
@@ -495,10 +519,10 @@ func (cm *Manager) syncToGitConfig() error {
 	return nil
 }
 
-// Save saves the current configuration to file
+// Save writes the configuration using restrictive permissions to prevent token disclosure.
 func (cm *Manager) Save() error {
 	dir := filepath.Dir(cm.configPath)
-	if err := os.MkdirAll(dir, 0755); err != nil {
+	if err := os.MkdirAll(dir, 0700); err != nil {
 		return fmt.Errorf("failed to create config directory: %w", err)
 	}
 
@@ -507,13 +531,47 @@ func (cm *Manager) Save() error {
 		return fmt.Errorf("failed to marshal config: %w", err)
 	}
 
-	if err := os.WriteFile(cm.configPath, data, 0644); err != nil {
-		return fmt.Errorf("failed to write config file: %w", err)
-	}
-
+	// Validate before writing to avoid persisting invalid configs
 	if err := cm.config.Validate(); err != nil {
 		return fmt.Errorf("cannot save invalid config: %w", err)
 	}
+
+	// Atomic write configuration
+	tmpFile, err := os.CreateTemp(dir, ".ggcconfig-*.tmp")
+	if err != nil {
+		return fmt.Errorf("failed to create temp file: %w", err)
+	}
+	tmpName := tmpFile.Name()
+	if runtime.GOOS != "windows" {
+		_ = os.Chmod(tmpName, 0600)
+	}
+	if _, err := tmpFile.Write(data); err != nil {
+		_ = tmpFile.Close()
+		_ = os.Remove(tmpName)
+		return fmt.Errorf("failed to write temp config file: %w", err)
+	}
+	if err := tmpFile.Close(); err != nil {
+		_ = os.Remove(tmpName)
+		return fmt.Errorf("failed to close temp config file: %w", err)
+	}
+
+	// Basic atomic replace: on Windows, remove the target first
+	if runtime.GOOS == "windows" {
+		_ = os.Remove(cm.configPath)
+	}
+	if err := os.Rename(tmpName, cm.configPath); err != nil {
+		// Retry after removing destination if rename failed
+		_ = os.Remove(cm.configPath)
+		if err2 := os.Rename(tmpName, cm.configPath); err2 != nil {
+			_ = os.Remove(tmpName)
+			return fmt.Errorf("failed to replace config file: %w", err2)
+		}
+	}
+
+	if runtime.GOOS != "windows" {
+		_ = os.Chmod(cm.configPath, 0600)
+	}
+
 	return cm.syncToGitConfig()
 }
 
